==> haskell-dbus-hslogger-0.1.0.1-531-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-JV9WqyMHozKCJC1kiTm7fj
key:                  dbus-hslogger-0.1.0.1-JV9WqyMHozKCJC1kiTm7fj
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  d8afc1870c09dcc28f05212e86f0a6fe
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-JV9WqyMHozKCJC1kiTm7fj
depends:
    base-4.16.4.0 dbus-1.3.1-CHKoLimmtsbHgHdJPuOO2J
    hslogger-1.3.1.2-GdSqzdUQbNiJnHwr0PdfmW

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus-hslogger-0.1.0.1-532-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-7rT4qxkTNAdYFrypWJRYc
key:                  dbus-hslogger-0.1.0.1-7rT4qxkTNAdYFrypWJRYc
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  0b5e98fdda7ba4ef95eaf06a1fb9eba6
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-7rT4qxkTNAdYFrypWJRYc
depends:
    base-4.16.4.0 dbus-1.3.1-1dTxxX9MaqcK7bQEpbWGsH
    hslogger-1.3.1.2-GdSqzdUQbNiJnHwr0PdfmW

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
